/*******************************************************************************
 * PROJECT         Senator 24/80
 * FILE            B30202_Pdm.DDL
 * RevNo.:         $Rev: $
 *------------------------------------------------------------------------------
 * LANGUAGE        HART-DDL, PROFIBUS-EDDL, FF-DDL
 * TOOLS           Code analysis:
 *                  is EDD Workbench v1.4.1
 *                 Tokenizer:
 *                  HCF_TOOL-24 Tokenizer Ver 5.1.12
 *                  HCF_TOOL-24 Tokenizer Ver 6.3.5
 *                  HCF_TOOL-24 Tokenizer Ver 8.1.32
 *                  SIMATIC PDM V9.0 + SP1
 * TARGETSYSTEM    SDC625 / FC375/475 / AMS / PDM / FDM
 *------------------------------------------------------------------------------
 * DESCRIPTION     Basis of Device Description
 *                 contains DD identification
 *                 and includes all other device description parts
 *
 ******************************************************************************/

/*
 * LOG:
 * Dev/DD  date     author  mark    reason
 * 01.01   16-11-14 GeorgB          1st version
 */

//MANUFACTURER TOKYO_KEISO, DEVICE_TYPE _SENATOR_24_80, DEVICE_REVISION 02, DD_REVISION 01
// IDs defined numerical here because otherwise the PDM tokenizer issues an
// error message unless the PDM list of HART device types "SI__DEV01.cfg"
// contains the respective entry
MANUFACTURER 179, DEVICE_TYPE 45826, DEVICE_REVISION 02, DD_REVISION 01

// DD version string according to NAMUR recommendation
// Level 1 refers to the DEVICE_TYPE and is therefore always "01" fixed
// Level 2 refers to the DEVICE_REVISION
// Level 3 refers to the DD_REVISION
#define G_ST5_VERSION_DD \
    "02.11"

// DD version string supplement according to NAMUR recommendation
// "X 01" for special software, numbering 01 to n
// "PRE 01" for preliminary software, numbering 01 to n
#define G_ST11_VERSION_DD_SUPPLEMENT \
    "_PRE2_1"
#ifndef G_ST11_VERSION_DD_SUPPLEMENT
  #define G_ST11_VERSION_DD_SUPPLEMENT \
    "           "
#endif

// Help text for the local variable for displaying the DD version string
// according to NAMUR recommendation NE 53
#define hlpVersionDd \
    "|en|Version number of the device description according to NAMUR recommendation. " \
        "\r\nYou are currently working with version: " G_ST5_VERSION_DD G_ST11_VERSION_DD_SUPPLEMENT \
    "|de|Version der Device-Description gem? NAMUR-Empfehlung. " \
        "\r\nSie arbeiten gerade mit Version: " G_ST5_VERSION_DD G_ST11_VERSION_DD_SUPPLEMENT

#define dscNameManufacturer \
    "Hawk"

#define G_PTH_IMAGE_MANUFACTURER    "B30202_MANUF.gif"

#define dscNameDevice \
    "Senator 24/80"

#define G_PTH_IMAGE_DEVICE          "B30202_DEVICE.gif"

#define G_ELS_MANUFACTURER_ID_PL \
    {  179, dscNameManufacturer }

#define G_ELS_DEVICE_TYPE_PL \
    { 45826, dscNameDevice }

#define G_ELS_EXP_DEVICE_TYPE_PL \
    { 0xB302, dscNameDevice },

#define G_PTH_IMAGE_ORIENT_PI                   "B30202_ORIENT_PI.jpg"

#define G_PTH_IMAGE_ORIENT_PI_SENSOR            "B30202_ORIENT_PI_SENSOR.jpg"

#define G_PTH_IMAGE_ORIENT_PI_CALIBRATION       "B30202_ORIENT_PI_CALIBRATION.jpg"

#define G_PTH_IMAGE_ORIENT_PI_FILTER            "B30202_ORIENT_PI_FILTER.jpg"

#define G_PTH_IMAGE_ORIENT_PI_SELFTEST          "B30202_ORIENT_PI_SELFTEST.jpg"

#define G_PTH_IMAGE_ORIENT_IO_CURRENT           "B30202_ORIENT_IO_CURRENT.jpg"

#define G_PTH_IMAGE_ORIENT_IO_FREQUENCY         "B30202_ORIENT_IO_FREQUENCY.jpg"

#define G_PTH_IMAGE_ORIENT_IO_STATUS            "B30202_ORIENT_IO_STATUS.jpg"

#define G_PTH_IMAGE_ORIENT_IO_CONTROL           "B30202_ORIENT_IO_CONTROL.jpg"

#define G_PTH_IMAGE_ORIENT_IO_TOTALIZER         "B30202_ORIENT_IO_TOTALIZER.jpg"

#define G_PTH_IMAGE_ORIENT_IO_SELECTION         "B30202_ORIENT_IO_SELECTION.jpg"

#define G_PTH_IMAGE_ORIENT_DISPLAY              "B30202_ORIENT_DISPLAY.jpg"

#define G_PTH_IMAGE_ORIENT_HART                 "B30202_ORIENT_HART.jpg"

#define G_PTH_IMAGE_STATUS_DIAGNOSIS_ACTIVE     "B30202_STATUS_DIAGNOSIS_ACTIVE.png"

#define G_PTH_IMAGE_STATUS_FAILURE              "B30202_STATUS_FAILURE.png"

#define G_PTH_IMAGE_STATUS_FUNCTION_CHECK       "B30202_STATUS_FUNCTION_CHECK.png"

#define G_PTH_IMAGE_STATUS_OUT_OF_SPECIFICATION "B30202_STATUS_OUT_OF_SPECIFICATION.png"

#define G_PTH_IMAGE_STATUS_MAINTENANCE_REQUIRED "B30202_STATUS_MAINTENANCE_REQUIRED.png"

#define G_PTH_IMAGE_STATUS_FAILURE_INACTIVE                 "B30202_STATUS_FAILURE_INACTIVE.png"

#define G_PTH_IMAGE_STATUS_FUNCTION_CHECK_INACTIVE          "B30202_STATUS_FUNCTION_CHECK_INACTIVE.png"

#define G_PTH_IMAGE_STATUS_OUT_OF_SPECIFICATION_INACTIVE    "B30202_STATUS_OUT_OF_SPECIFICATION_INACTIVE.png"

#define G_PTH_IMAGE_STATUS_MAINTENANCE_REQUIRED_INACTIVE    "B30202_STATUS_MAINTENANCE_REQUIRED_INACTIVE.png"


/*******************************************************************************
 * includes
 * (don't change the order)
 *******************************************************************************/
#include "Methods.h"
#include "Macros.h"

/* Switch definitions, text replacement and macros */
#include "B30202_MAC.dd"

/* Dictionary */
#include "B30202_DIC.dd"

// device variables and analog channels according to HART standard
#include "B30202_DVAC_MDL_Pdm.dd"

// Import/adaptation of standard tables, commands, methods
//#include "B30202_IMP.dd"
#include "B30202_IMP_Pdm.dd"

// Include of Real Time Clock variables and commands
//#include "B30202_RTC_Pdm.dd"

// Burst mode
#ifdef G_DEF_SUPPORT_BURST
#include "B30202_BURST_MDL_Pdm.dd"
#endif

// Data model
#include "B30202_MDL.dd"

// Commands
#include "B30202_CMD.dd"
#include "B30202_SCMD.dd"

// Menues
#include "B30202_MNU.dd"

// Up-/Download menus etc.
#include "B30202_GEN.dd"
